@@ -1,7 +1,7 @@
 #ifndef __GDICT_APPLET_H_
 #define __GDICT_APPLET_H_
 
-/* $Id: gdict-applet.h,v 1.7 2002/05/10 18:18:29 gman Exp $ */
+/* $Id: gdict-applet.h,v 1.8 2003/06/05 06:10:42 dcransto Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim@cs.cmu.edu>
@@ -22,7 +22,7 @@ typedef struct _GDictApplet {
 	GtkWidget *applet_widget;
 	GtkWidget *button_widget;
 	GtkWidget *image;
-	GtkWidget *vbox_widget;
+	GtkWidget *box;
 	GtkWidget *entry_widget;
 	GtkWidget *handlebox_widget;
 	PanelAppletOrient orient;
