@@ -33,43 +33,17 @@ extern "C" {
 #pragma }
 #endif
 
-#include <gnome.h>
-
-#define CDDB_DISCLOSURE_TYPE (cddb_disclosure_get_type ())
-#define CDDB_DISCLOSURE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CDDB_DISCLOSURE_TYPE, CDDBDisclosure))
-#define CDDB_DISCLOSURE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CDDB_DISCLOSURE_TYPE, CDDBDisclosureClass))
-#define IS_CDDB_DISCLOSURE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CDDB_DISCLOSURE_TYPE))
-#define IS_CDDB_DISCLOSURE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CDDB_DISCLOSURE_TYPE))
 #define ICON_SIZE 24.0
 
-typedef struct _CDDBDisclosure CDDBDisclosure;
-typedef struct _CDDBDisclosureClass CDDBDisclosureClass;
-typedef struct _CDDBDisclosurePrivate CDDBDisclosurePrivate;
-
-struct _CDDBDisclosure {
-	GtkCheckButton parent;
-	CDDBDisclosurePrivate *priv;
-};
-
-struct _CDDBDisclosureClass {
-	GtkCheckButtonClass parent_class;
-};
-
-GType 		
-cddb_disclosure_get_type 	(void);
-
-GtkWidget *
-cddb_disclosure_new 		(const char *shown,
-				 const char *hidden);
-void
-cddb_disclosure_set_container 	(CDDBDisclosure *disclosure,
-				 GtkWidget *container);
 gboolean  	
 is_path_hidden 			(const gchar *path);
 
 gboolean  	
 is_path_in_home_folder 		(const gchar *path);
 
+gboolean  	
+is_path_in_mount_folder		(const gchar *path);
+
 gboolean
 file_extension_is 		(const char *filename, 
 		   		 const char *ext);
@@ -82,12 +56,12 @@ limit_string_to_x_lines		(GString *string,
 gchar *	
 escape_single_quotes 		(const gchar *string);
 
+gchar *
+remove_mnemonic_character	(const gchar *string);
+
 gint 	 	
 count_of_char_in_string		(const gchar *string, 
 				 const gchar q);
-gchar *    	
-get_date 			(const time_t file_time_raw);
-
 gchar *   	
 get_readable_date 		(const time_t file_time_raw);
 
@@ -115,6 +89,24 @@ open_file_with_application 	(const gchar *filename);
 gboolean
 launch_file 			(const gchar *filename);
 
+gboolean 
+gsearchtool_gconf_get_boolean 	(const gchar *key);
+
+void
+gsearchtool_gconf_set_boolean 	(const gchar *key, 
+				 const gboolean flag);
+
+gchar *
+gsearchtool_unique_filename 	(const gchar *dir,
+				 const gchar *suffix);
+			      
+GtkWidget *
+gsearchtool_hig_dialog_new      (GtkWindow      *parent,
+                                 GtkDialogFlags flags,
+                                 GtkButtonsType buttons,
+                                 const gchar    *header,
+                                 const gchar    *message);
+				 			      
 #ifdef __cplusplus
 }
 #endif
