@@ -20,6 +20,9 @@
     ---------------------------------------------------------------------- */
 
 #include <config.h>
+#ifdef __CYGWIN__
+#define timezonevar
+#endif
 #include <gnome.h>
 #include <locale.h>
 #include <errno.h>
@@ -33,7 +36,6 @@
  */
 
 #define MAX_NUM_LOGS             10
-#define DEF_NUM_LOGS             3
 
 /*
  * -------------------
@@ -178,7 +180,6 @@ OpenLogFile (char *filename)
    Log *tlog;
    LogLine *line;
    char buffer[1024];
-   int i, j;
 
    /* Check that the file exists and is readable and is a
       logfile */
